@@ -1,8 +1,8 @@
 __name__ = "pyston"
 __author__ = "Fang"
-__version__ = "1.1.1"
+__version__ = "1.2.1"
 
-from .client import PystonClient
+from .client import PystonClient,File
 from . import http_handler
 from . import exceptions
-from . import response
\ No newline at end of file
+from . import models
\ No newline at end of file
